@@ -19,40 +19,40 @@
 #define __ANN_CYBENKO_H
 
 #include <ann_weight.h>
-#include <ann_nfb_perc.h>
-#include <ann_nfb_mlayer.h>
+#include <ann_nit_perc.h>
+#include <ann_nit_mlayer.h>
 
 namespace ANN
 {
 
-  NFB_mlayer *
+  NIT_mlayer *
   create_Cybenko(Log *log, const char *label, size_t in, size_t hidden,
                  size_t out, W_FB &w, Act &act=Act::sigmoidal, bool bias=true);
-  inline NFB_mlayer *
+  inline NIT_mlayer *
   create_Cybenko(Log *log, const char *label, size_t in, size_t hidden,
                  size_t out, W_FB &w, bool bias)
   { return create_Cybenko(log,label,in,hidden,out,w,Act::sigmoidal,bias); }
-  inline NFB_mlayer *
+  inline NIT_mlayer *
   create_Cybenko(Log *log, size_t in, size_t hidden, size_t out, W_FB &w,
                  Act &act=Act::sigmoidal, bool bias=true)
   { return create_Cybenko(log,0,in,hidden,out,w,act,bias); }
-  inline NFB_mlayer *
+  inline NIT_mlayer *
   create_Cybenko(Log *log, size_t in, size_t hidden, size_t out, W_FB &w,
                  bool bias)
   { return create_Cybenko(log,0,in,hidden,out,w,Act::sigmoidal,bias); }
-  inline NFB_mlayer *
+  inline NIT_mlayer *
   create_Cybenko(const char *label, size_t in, size_t hidden, size_t out,
                  W_FB &w, Act &act=Act::sigmoidal, bool bias=true)
   { return create_Cybenko(0,label,in,hidden,out,w,act,bias); }
-  inline NFB_mlayer *
+  inline NIT_mlayer *
   create_Cybenko(const char *label, size_t in, size_t hidden, size_t out,
                  W_FB &w, bool bias)
   { return create_Cybenko(0,label,in,hidden,out,w,Act::sigmoidal,bias); }
-  inline NFB_mlayer *
+  inline NIT_mlayer *
   create_Cybenko(size_t in, size_t hidden, size_t out, W_FB &w,
                  Act &act=Act::sigmoidal, bool bias=true)
   { return create_Cybenko(0,0,in,hidden,out,w,act,bias); }
-  inline NFB_mlayer *
+  inline NIT_mlayer *
   create_Cybenko(size_t in, size_t hidden, size_t out, W_FB &w, bool bias)
   { return create_Cybenko(0,0,in,hidden,out,w,Act::sigmoidal,bias); }
 
