@@ -18,9 +18,9 @@
 #ifndef __ANN_LOC_IO_H
 #define __ANN_LOC_IO_H
 
-#include <ctype.h>
 #include <iostream>
 
+#include <ann_use_size_t.h>
 #include <ann_loc.h>
 
 std::ostream &
