@@ -19,16 +19,11 @@
 #define __ANN_TERM_H
 
 #include <ann_array.h>
+#include <ann_use_nan.h>
 
 namespace ANN
 {
 
-  class NAV<double>
-  {
-  public:
-    static double get() { return NAN; }
-  };
-
   typedef Array<double> Term; /* training set term (weak container) */
   typedef ARRAY<double> TERM; /* training set term (strong container) */
   
