@@ -18,8 +18,6 @@
 #ifndef __ANN_TO_H
 #define __ANN_TO_H
 
-#include <ctype.h>
-
 namespace ANN
 {
   class TO;
@@ -79,7 +77,11 @@ namespace ANN
     /** single epoch of training **/
     virtual void          open();
     /* called every time epoch starts */
-    virtual void          adapt(const Term &in, Term &out)=0;
+    virtual bool          fb_accept(bool former) const;
+    /* tells wheter this elent accepts feed back */
+    virtual void          feed_back(const Term &in, const Term &out,
+                                    const Term *out_fb, Term *in_fb);
+    virtual void          adapt(const Term &in, Term &out);
     /* called to conduct epoch steps */
     virtual Status        close()=0;
     /* called every time epoch ends */
